import { Subject } from 'rxjs';
import { OptionViewBase } from '@/studio-core';
import HRDistributionService from '@/service/hrdistribution/hrdistribution-service';
import HRDistributionAuthService from '@/authservice/hrdistribution/hrdistribution-auth-service';
import OptionViewEngine from '@engine/view/option-view-engine';
import HRDistributionUIService from '@/uiservice/hrdistribution/hrdistribution-ui-service';

/**
 * 快速新建视图基类
 *
 * @export
 * @class HRDistributionV_002Base
 * @extends {OptionViewBase}
 */
export class HRDistributionV_002Base extends OptionViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof HRDistributionV_002Base
     */
    protected appDeName: string = 'hrdistribution';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof HRDistributionV_002Base
     */
    protected appDeKey: string = 'hrdistributionid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof HRDistributionV_002Base
     */
    protected appDeMajor: string = 'hrdistributionname';

    /**
     * 实体服务对象
     *
     * @type {HRDistributionService}
     * @memberof HRDistributionV_002Base
     */
    protected appEntityService: HRDistributionService = new HRDistributionService;

    /**
     * 实体权限服务对象
     *
     * @type HRDistributionUIService
     * @memberof HRDistributionV_002Base
     */
    public appUIService: HRDistributionUIService = new HRDistributionUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof HRDistributionV_002Base
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof HRDistributionV_002Base
     */
    protected model: any = {
        srfCaption: 'entities.hrdistribution.views.v_002.caption',
        srfTitle: 'entities.hrdistribution.views.v_002.title',
        srfSubTitle: 'entities.hrdistribution.views.v_002.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof HRDistributionV_002Base
     */
    protected containerModel: any = {
        view_form: { name: 'form', type: 'FORM' },
        view_okbtn: { name: 'okbtn', type: 'button', text: '确定', disabled: true },
        view_cancelbtn: { name: 'cancelbtn', type: 'button', text: '取消', disabled: false },
        view_leftbtn: { name: 'leftbtn', type: 'button', text: '左移', disabled: true },
        view_rightbtn: { name: 'rightbtn', type: 'button', text: '右移', disabled: true },
        view_allleftbtn: { name: 'allleftbtn', type: 'button', text: '全部左移', disabled: true },
        view_allrightbtn: { name: 'allrightbtn', type: 'button', text: '全部右移', disabled: true },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = 'cd7f9e0b57fdfdf34307ce460137b152';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof HRDistributionV_002Base
     */
    public engine: OptionViewEngine = new OptionViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof HRDistributionV_002Base
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            form: this.$refs.form,
            p2k: '0',
            keyPSDEField: 'hrdistribution',
            majorPSDEField: 'hrdistributionname',
            isLoadDefault: true,
        });
    }

    /**
     * form 部件 save 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HRDistributionV_002Base
     */
    public form_save($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'save', $event);
    }

    /**
     * form 部件 remove 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HRDistributionV_002Base
     */
    public form_remove($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'remove', $event);
    }

    /**
     * form 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HRDistributionV_002Base
     */
    public form_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'load', $event);
    }


}