import { Prop, Provide, Emit, Model } from 'vue-property-decorator';
import { Subject, Subscription } from 'rxjs';
import { Watch, GridControlBase } from '@/studio-core';
import HRRewardService from '@/service/hrreward/hrreward-service';
import MainService from './main-grid-service';
import HRRewardUIService from '@/uiservice/hrreward/hrreward-ui-service';
import { FormItemModel } from '@/model/form-detail';


/**
 * grid部件基类
 *
 * @export
 * @class GridControlBase
 * @extends {MainGridBase}
 */
export class MainGridBase extends GridControlBase {

    /**
     * 获取部件类型
     *
     * @protected
     * @type {string}
     * @memberof MainGridBase
     */
    protected controlType: string = 'GRID';

    /**
     * 建构部件服务对象
     *
     * @type {MainService}
     * @memberof MainGridBase
     */
    public service: MainService = new MainService({ $store: this.$store });

    /**
     * 实体服务对象
     *
     * @type {HRRewardService}
     * @memberof MainGridBase
     */
    public appEntityService: HRRewardService = new HRRewardService({ $store: this.$store });

    /**
     * 应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof MainGridBase
     */
    protected appDeName: string = 'hrreward';

    /**
     * 应用实体中文名称
     *
     * @protected
     * @type {string}
     * @memberof MainGridBase
     */
    protected appDeLogicName: string = '奖励惩罚';

    /**
     * 界面UI服务对象
     *
     * @type {HRRewardUIService}
     * @memberof MainBase
     */  
    public appUIService:HRRewardUIService = new HRRewardUIService(this.$store);

    /**
     * 界面行为模型
     *
     * @type {*}
     * @memberof MainBase
     */  
    public ActionModel: any = {
    };

    /**
     * 本地缓存标识
     *
     * @protected
     * @type {string}
     * @memberof MainBase
     */
    protected localStorageTag: string = 'hrreward_main_grid';

    /**
     * 所有列成员
     *
     * @type {any[]}
     * @memberof MainGridBase
     */
    public allColumns: any[] = [
        {
            name: 'rewardtype',
            label: '奖惩分类',
            langtag: 'entities.hrreward.main_grid.columns.rewardtype',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
        {
            name: 'hrrewardname',
            label: '奖惩名称',
            langtag: 'entities.hrreward.main_grid.columns.hrrewardname',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
        {
            name: 'rewardlevel',
            label: '奖惩级别',
            langtag: 'entities.hrreward.main_grid.columns.rewardlevel',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
        {
            name: 'rewardmoney',
            label: '奖惩金额',
            langtag: 'entities.hrreward.main_grid.columns.rewardmoney',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
        {
            name: 'rewardtime',
            label: '奖惩时间',
            langtag: 'entities.hrreward.main_grid.columns.rewardtime',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
        {
            name: 'rewardevent',
            label: '奖惩事件',
            langtag: 'entities.hrreward.main_grid.columns.rewardevent',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
    ]

    /**
     * 获取表格行模型
     *
     * @type {*}
     * @memberof MainGridBase
     */
    public getGridRowModel(){
        return {
          srfkey: new FormItemModel(),
        }
    }

    /**
     * 属性值规则
     *
     * @type {*}
     * @memberof MainGridBase
     */
    public rules: any = {
        srfkey: [
            { required: false, validator: (rule:any, value:any, callback:any) => { return (rule.required && (value === null || value === undefined || value === "")) ? false : true;}, message: '奖励惩罚标识 值不能为空', trigger: 'change' },
            { required: false, validator: (rule:any, value:any, callback:any) => { return (rule.required && (value === null || value === undefined || value === "")) ? false : true;}, message: '奖励惩罚标识 值不能为空', trigger: 'blur' },
        ],
    }

    /**
     * 获取对应列class
     *
     * @type {*}
     * @memberof MainBase
     */
    public hasRowEdit: any = {
        'rewardtype':false,
        'hrrewardname':false,
        'rewardlevel':false,
        'rewardmoney':false,
        'rewardtime':false,
        'rewardevent':false,
    };

    /**
     * 获取对应列class
     *
     * @param {*} $args row 行数据，column 列数据，rowIndex 行索引，列索引
     * @returns {void}
     * @memberof MainBase
     */
    public getCellClassName(args: {row: any, column: any, rowIndex: number, columnIndex: number}): any {
        return ( this.hasRowEdit[args.column.property] && this.actualIsOpenEdit ) ? "edit-cell" : "info-cell";
    }


    /**
     * 导出数据格式化
     *
     * @param {*} filterVal
     * @param {*} jsonData
     * @param {any[]} [codelistColumns=[]]
     * @returns {Promise<any>}
     * @memberof MainGridBase
     */
    public async formatExcelData(filterVal: any, jsonData: any, codelistColumns?: any[]): Promise<any> {
        return super.formatExcelData(filterVal, jsonData, [
        ]);
    }

}